# DefaultTextMarkupDocumentAllOfContent


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** |  | 
**attrs** | [**Attrs**](Attrs.md) |  | [optional] 
**content** | [**List[ParagraphDocumentNodeAllOfContent]**](ParagraphDocumentNodeAllOfContent.md) |  | [optional] 

## Example

```python
from src.client.generated.models.default_text_markup_document_all_of_content import DefaultTextMarkupDocumentAllOfContent

# TODO update the JSON string below
json = "{}"
# create an instance of DefaultTextMarkupDocumentAllOfContent from a JSON string
default_text_markup_document_all_of_content_instance = DefaultTextMarkupDocumentAllOfContent.from_json(json)
# print the JSON string representation of the object
print(DefaultTextMarkupDocumentAllOfContent.to_json())

# convert the object into a dict
default_text_markup_document_all_of_content_dict = default_text_markup_document_all_of_content_instance.to_dict()
# create an instance of DefaultTextMarkupDocumentAllOfContent from a dict
default_text_markup_document_all_of_content_from_dict = DefaultTextMarkupDocumentAllOfContent.from_dict(default_text_markup_document_all_of_content_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


